@@ -1,5 +1,8 @@
 __all__ = ['process',
            'thread',
+           'waitfortasks',
+           'waitforthreads',
+           'waitforqueues',
            'synchronized',
            'sighandler',
            'Task',
@@ -11,5 +14,6 @@ __all__ = ['process',
 
 from . import thread
 from . import process
-from .pebble import synchronized, sighandler, Task
+from .pebble import synchronized, sighandler, waitfortasks, waitforthreads
+from .pebble import waitforqueues, Task
 from .pebble import PebbleError, TaskCancelled, TimeoutError, ProcessExpired
